@@ -1,15 +1,15 @@
 context("ef_hdv_speed")
 
 test_that("ef_hdv_speed works", {
-  expect_output(ef_hdv_speed(v = "Trucks",
+  expect_equal(round(ef_hdv_speed(v = "Trucks",
                             t = "RT",
                             g = "<=7.5",
                             e = "II",
                             gr = 0,
                             l = 0.5,
-                            p = "N_50nm_urban",
-                            speed = Speed(30)),
-                "U.?")
+                            p = "CO",
+                            speed = Speed(30))),
+                EmissionFactors(1))
 })
 
 
@@ -30,42 +30,12 @@ test_that("ef_hdv_speed works", {
                EmissionFactors(1))
 })
 
-test_that("ef_hdv_speed works", {
-  expect_equal(ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
-                            l = 0.5, p = "Hg", show.equation = FALSE)(30), 5.350296e-07)
-})
 
 test_that("ef_hdv_speed works", {
   expect_equal(round(ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
                             l = 0.5, p = "CO2", show.equation = FALSE)(30)), 317)
 })
 
-test_that("ef_hdv_speed works", {
-  expect_equal(round(ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
-                                  l = 0.5, p = "napthalene", show.equation = FALSE)(30)), 0)
-})
-
-test_that("ef_hdv_speed works", {
-  expect_equal(round(ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
-                                  l = 0.5, p = "PCB", show.equation = FALSE)(30)), 0)
-})
-
-test_that("ef_hdv_speed works", {
-  expect_equal(round(ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
-                                  l = 0.5, p = "N_rural", show.equation = FALSE)(30)), 3.19e+14)
-})
-
-test_that("ef_hdv_speed stops", {
-  expect_error(ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
-                                  l = 0.5, p = "N_rural", speed = 1),
-               "speed.?")
-})
-
-test_that("ef_hdv_speed stops", {
-  expect_error(ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
-                            l = 0.5, p = "N_rural", speed = units::set_units(1, "t/km")),
-               "Units.?")
-})
 
 test_that("ef_hdv_speed works", {
   expect_equal(ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
@@ -97,13 +67,6 @@ test_that("ef_hdv_speed stops", {
                "sp?")
 })
 
-
-test_that("ef_hdv_speed prints", {
-  expect_output(ef_hdv_speed(v = "Trucks",t = "RT", g = "<=7.5", e = "II", gr = 0,
-                             l = 0.5, p = "N_50nm_urban", speed = Speed(0)),
-                "U.?")
-})
-
 test_that("ef_hdv_speed works", {
   expect_equal(round(ef_hdv_speed(v = "Trucks",
                                   t = "RT",
@@ -154,17 +117,6 @@ test_that("ef_hdv_speed stops", {
                "Add.?")
 })
 
-test_that("ef_hdv_speed stops", {
-  expect_output(ef_hdv_speed(v = "Trucks",
-                            t = "RT",
-                            g = "<=7.5",
-                            e = "II",
-                            gr = 0,
-                            l = 0.5,
-                            p = "AS_rural",
-                            speed = Speed(0)),
-               "U.?")
-})
 test_that("ef_hdv_speed stops", {
   expect_equal(round(ef_hdv_speed(v = "Trucks",
                             t = "RT",
