@@ -4,7 +4,7 @@ data(pc_profile)
 pc_week <- temp_fact(net$ldv + net$hdv, pc_profile)
 
 test_that("netspeed works", {
-  expect_equal(round(netspeed(pc_week, net$ps, net$ffs, net$capacity, net$lkm, alpha = 1)[1,1]),
+  expect_equal(round(netspeed(pc_week, net$ps, net$ffs, net$capacity, net$lkm, alpha = 1, dist = units(net$ps)$numerator)[1,1]),
                round(Speed(59.91954)))
 })
 
